<?php
/*
Plugin Name: EasyToolsWP Login Redirect Settings
Description: Adds a settings page to choose the redirect endpoint after login, including WooCommerce products and custom frontend URLs.
Version: 1.2
Author: EasyToolsWP.com
*/

// Prevent direct file access
if (!defined('ABSPATH')) {
    exit;
}

// Register a submenu page under Settings
function add_redirect_settings_page() {
    add_options_page(
        'Redirect After Login Settings',    // Page Title
        'Redirect After Login',             // Menu Title
        'manage_options',                   // Capability
        'redirect-after-login',             // Menu Slug
        'redirect_settings_page_callback'   // Callback Function
    );
}
add_action('admin_menu', 'add_redirect_settings_page');

// Callback to display the settings page
function redirect_settings_page_callback() {
    // Save the setting when the form is submitted
    if (isset($_POST['redirect_endpoint'])) {
        update_option('redirect_after_login_endpoint', sanitize_text_field($_POST['redirect_endpoint']));
    }

    if (isset($_POST['custom_frontend_url'])) {
        update_option('custom_frontend_url', esc_url_raw($_POST['custom_frontend_url']));
    }

    echo '<div class="updated"><p>Settings saved.</p></div>';

    // Get the currently selected value from the database
    $current_endpoint = get_option('redirect_after_login_endpoint', 'dashboard');
    $custom_frontend_url = get_option('custom_frontend_url', '');
    ?>

    <div class="wrap">
        <h1>Redirect After Login Settings</h1>
        <form method="post" action="">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Select Login Endpoint</th>
                    <td>
                        <select name="redirect_endpoint">
                            <option value="dashboard" <?php selected($current_endpoint, 'dashboard'); ?>>Dashboard (Default)</option>
                            <option value="pages" <?php selected($current_endpoint, 'pages'); ?>>Pages</option>
                            <option value="posts" <?php selected($current_endpoint, 'posts'); ?>>Posts</option>
                            <?php if (class_exists('WooCommerce')) : ?>
                                <option value="orders" <?php selected($current_endpoint, 'orders'); ?>>WooCommerce Orders</option>
                                <option value="products" <?php selected($current_endpoint, 'products'); ?>>WooCommerce Products</option>
                            <?php endif; ?>
                            <option value="custom" <?php selected($current_endpoint, 'custom'); ?>>Frontend URL</option>
                        </select>
                    </td>
                </tr>
                <tr valign="top" id="custom-url-row" style="<?php echo ($current_endpoint === 'custom') ? '' : 'display:none;'; ?>">
                    <th scope="row">Custom Frontend URL</th>
                    <td>
                        <input type="url" name="custom_frontend_url" value="<?php echo esc_url($custom_frontend_url); ?>" placeholder="https://example.com" class="regular-text">
                        <p class="description">Enter the URL where users should be redirected after login.</p>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
        <script>
            document.querySelector('select[name="redirect_endpoint"]').addEventListener('change', function() {
                document.getElementById('custom-url-row').style.display = (this.value === 'custom') ? '' : 'none';
            });
        </script>
    </div>
    <?php
}

// Redirect after login based on the selected setting
function redirect_to_selected_endpoint($redirect_to, $request, $user) {
    if (isset($user->roles) && is_array($user->roles)) {
        $current_endpoint = get_option('redirect_after_login_endpoint', 'dashboard');
        $custom_frontend_url = get_option('custom_frontend_url', '');

        switch ($current_endpoint) {
            case 'pages':
                $redirect_to = admin_url('edit.php?post_type=page');
                break;
            case 'posts':
                $redirect_to = admin_url('edit.php');
                break;
            case 'orders':
                $redirect_to = admin_url('admin.php?page=wc-orders');
                break;
            case 'products':
                if (class_exists('WooCommerce')) {
                    $redirect_to = admin_url('edit.php?post_type=product');
                } else {
                    $redirect_to = admin_url(); // Fallback if WooCommerce is not active
                }
                break;
            case 'custom':
                if (!empty($custom_frontend_url)) {
                    $redirect_to = esc_url($custom_frontend_url);
                } else {
                    $redirect_to = admin_url(); // Fallback if custom URL is empty
                }
                break;
            default:
                $redirect_to = admin_url();
        }
    }
    return $redirect_to;
}
add_filter('login_redirect', 'redirect_to_selected_endpoint', 10, 3);

?>
